import os
import re
from django.conf import settings
from django.apps import apps
from django.utils.translation import get_language
from django_restful_translator.models import TranslatableModel, Translation


def get_translation(instance, field_name, as_dict=False):
    translations = list(instance.translations.all())

    if as_dict:
        return {trans.language: trans.field_value for trans in translations if trans.field_name == field_name}
    else:
        user_language = get_language()
        if user_language != settings.LANGUAGE_CODE:
            for trans in translations:
                if trans.field_name == field_name and trans.language == user_language:
                    return trans.field_value
        return getattr(instance, field_name)


def fetch_translatable_fields(language):
    models = apps.get_models()
    translatable_models = [model for model in models if issubclass(model, TranslatableModel)]

    collected_translations = []

    for model in translatable_models:
        objects = model.objects.all().prefetch_related('translations')
        for obj in objects:
            for field_name in model.translatable_fields:
                original_field_value = getattr(obj, field_name)

                if original_field_value is None or original_field_value == '':
                    continue

                trans = next((t for t in obj.translations.all() if
                              t.field_name == field_name and t.language == language), None)

                if not trans:
                    trans = Translation(
                        content_object=obj,
                        field_name=field_name,
                        language=language,
                        field_value=original_field_value if language == settings.LANGUAGE_CODE else ""
                    )

                collected_translations.append(trans)
    return collected_translations


def get_po_file_path(language):
    po_path = os.path.join(settings.BASE_DIR, 'drt_locale', language, 'LC_MESSAGES')
    os.makedirs(po_path, exist_ok=True)
    po_file_path = os.path.join(po_path, 'django.po')
    return po_file_path


def get_po_metadata():
    return {
        'Content-Type': 'text/plain; charset=UTF-8',
        'Content-Transfer-Encoding': '8bit',
    }


def replace_placeholders_with_tokens(text):
    placeholders = re.findall(r'\{.*?\}', text)
    tokens = {}
    counter = 1
    for placeholder in placeholders:
        token = f"__TOKEN{counter}__"
        counter += 1
        tokens[token] = placeholder
        text = text.replace(placeholder, token)
    return text, tokens


def replace_tokens_with_placeholders(text, tokens):
    for token, placeholder in tokens.items():
        text = text.replace(token, placeholder)
    return text


def get_batches(data, batch_size):
    for i in range(0, len(data), batch_size):
        yield data[i:i + batch_size]



import html

from concurrent.futures import ThreadPoolExecutor, as_completed

from django.conf import settings
from django.core.management.base import BaseCommand

from django_restful_translator.translation_providers import TranslationProvider
from django_restful_translator.utils import fetch_translatable_fields, replace_placeholders_with_tokens, \
    replace_tokens_with_placeholders, get_batches


class Command(BaseCommand):
    help = 'Translate model fields'
    provider_names = [cls.name for cls in TranslationProvider.__subclasses__()]

    def add_arguments(self, parser):
        parser.add_argument(
            '--language',
            type=str,
            help='Specify the language to which the fields should be translated'
        )
        parser.add_argument(
            '--target_language',
            type=str,
            help='Specify the provider target language if it differs from the setting language',
            default=None
        )
        parser.add_argument(
            '--provider',
            type=str,
            help='Specify the translation provider to use for the translation. Available providers: ' + ', '.join(
                self.provider_names)
        )
        parser.add_argument(
            '--all',
            action='store_true',
            help='Translate even existing translations'
        )
        parser.add_argument(
            '--workers',
            type=int,
            default=4,
            help='Number of worker threads to use for translation'
        )
        parser.add_argument(
            '--without_batch',
            action='store_true',
            help='One request per one unit of text'
        )

    def translate_item(self, translation, provider, target_language):
        text = getattr(translation.content_object, translation.field_name)
        text_with_tokens, tokens = replace_placeholders_with_tokens(text)
        translated_text = provider.translate_text(text_with_tokens, settings.LANGUAGE_CODE, target_language)
        translated_text = replace_tokens_with_placeholders(translated_text, tokens)
        decoded_text = html.unescape(translated_text)
        translation.field_value = decoded_text
        translation.save()

        self.stdout.write(
            f'Translated {translation.content_object._meta.model_name} field {translation.field_name} to {target_language}')

    def translate_batch(self, translations, provider, target_language):
        content_to_translate = []
        original_translations = []
        tokens_list = []
        for translation in translations:
            original_text = getattr(translation.content_object, translation.field_name)
            text_with_tokens, tokens = replace_placeholders_with_tokens(original_text)
            content_to_translate.append(text_with_tokens)
            tokens_list.append(tokens)
            original_translations.append(translation)

        translated_texts = provider.translate_text(content_to_translate, settings.LANGUAGE_CODE,
                                                   target_language)

        for translation, tokens, translated_text in zip(original_translations, tokens_list, translated_texts):
            translated_text_with_placeholders = replace_tokens_with_placeholders(translated_text, tokens)
            translation.field_value = html.unescape(translated_text_with_placeholders)
            translation.save()
            self.stdout.write(
                f'Translated {translation.content_object._meta.model_name} field {translation.field_name} to {target_language}')

    def handle(self, *args, **options):
        language = options['language']
        target_language = options['target_language']
        provider_name = options['provider']
        translate_all = options['all']
        workers = options['workers']
        without_batch = options['without_batch']

        if not target_language:
            target_language = language

        if language not in [lang[0] for lang in settings.LANGUAGES]:
            self.stdout.write(f'Unknown language: {language}')
            return

        if language == settings.LANGUAGE_CODE:
            self.stdout.write('Cannot translate to the same language')
            return

        available_providers = {cls.name: cls for cls in TranslationProvider.__subclasses__()}
        provider_class = available_providers.get(provider_name)
        if not provider_class:
            self.stdout.write(f'Unknown provider: {provider_name}')
            return

        provider = provider_class()
        translations_qs = fetch_translatable_fields(language)
        for_translation_list = []
        if translate_all is False:
            for translation in translations_qs:
                if len(translation.field_value) > 0:
                    continue
                for_translation_list.append(translation)
        else:
            for_translation_list = translations_qs

        if without_batch or provider.batch_size == 1:
            with ThreadPoolExecutor(max_workers=workers) as executor:
                futures = [
                    executor.submit(self.translate_item, trans, provider, target_language)
                    for trans in for_translation_list
                ]

                for future in as_completed(futures):
                    try:
                        future.result()
                    except Exception as e:
                        self.stdout.write(self.style.ERROR(f"Error occurred: {e}"))
        else:
            with ThreadPoolExecutor(max_workers=workers) as executor:
                futures = [
                    executor.submit(self.translate_batch, batch, provider, target_language)
                    for batch in get_batches(for_translation_list, provider.batch_size)
                ]

                for future in as_completed(futures):
                    try:
                        future.result()
                    except Exception as e:
                        self.stdout.write(self.style.ERROR(f"Error occurred: {e}"))



from django.conf import settings
from django.contrib.contenttypes.fields import GenericForeignKey, GenericRelation
from django.db import models


class Translation(models.Model):
    content_type = models.ForeignKey('contenttypes.ContentType', on_delete=models.CASCADE)
    object_id = models.CharField(max_length=255)
    content_object = GenericForeignKey('content_type', 'object_id')
    language = models.CharField(max_length=10, choices=settings.LANGUAGES)
    field_name = models.CharField(max_length=255)
    field_value = models.TextField()
    created_at = models.DateTimeField(blank=True, auto_now_add=True)
    updated_at = models.DateTimeField(blank=True, auto_now=True)

    class Meta:
        unique_together = ('content_type', 'object_id', 'language', 'field_name',)
        ordering = ('-created_at',)

    def __str__(self):
        return f'{self.content_type}__{self.field_name}__{self.object_id}'


class TranslatableModel(models.Model):
    translations = GenericRelation(Translation)
    translatable_fields = []

    class Meta:
        abstract = True



from django.conf import settings
from django.contrib.contenttypes.models import ContentType
from django.utils import translation
from rest_framework import serializers

from django_restful_translator.models import Translation
from django_restful_translator.utils import get_translation
from .fields import GetTextCharField, AutoTranslatableDictField


class TranslatableDBSerializer(serializers.ModelSerializer):
    class Meta:
        model = None

    def to_representation(self, instance):
        data = super().to_representation(instance)
        for field_name in instance.translatable_fields:
            if field_name in self.fields:
                data[field_name] = get_translation(instance, field_name)
        return data


class TranslatableDBDictSerializer(serializers.ModelSerializer):
    class Meta:
        model = None

    def to_representation(self, instance):
        data = super().to_representation(instance)
        for field_name in instance.translatable_fields:
            if field_name in self.fields:
                data[field_name] = {settings.LANGUAGE_CODE: getattr(instance, field_name)} | get_translation(instance,
                                                                                                             field_name,
                                                                                                             as_dict=True)
        return data


class TranslatableWritableDBDictSerializer(serializers.ModelSerializer):
    class Meta:
        model = None  # Set your model

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        for field_name in self.Meta.model.translatable_fields:
            if field_name in self.fields:
                if not isinstance(self.fields[field_name], AutoTranslatableDictField):
                    self.fields[field_name] = AutoTranslatableDictField(required=False)

    def to_representation(self, instance):
        data = super().to_representation(instance)
        for field_name in instance.translatable_fields:
            if field_name in self.fields:
                data[field_name] = {settings.LANGUAGE_CODE: getattr(instance, field_name)} | get_translation(instance,
                                                                                                             field_name,
                                                                                                             as_dict=True)
        return data

    def create(self, validated_data):
        translations_data = self.extract_translations_data(validated_data)
        instance = super().create(validated_data)
        self.update_translations(instance, translations_data, skip_primary=True)
        return instance

    def update(self, instance, validated_data):
        translations_data = self.extract_translations_data(validated_data)
        instance = super().update(instance, validated_data)
        self.update_translations(instance, translations_data, skip_primary=True)
        return instance

    def extract_translations_data(self, validated_data):
        translations_data = {}
        for field in self.Meta.model.translatable_fields:
            if field in validated_data and isinstance(validated_data[field], dict):
                primary_lang_value = validated_data[field].pop(settings.LANGUAGE_CODE, None)
                if validated_data[field]:
                    translations_data[field] = validated_data.pop(field)
                if primary_lang_value is not None:
                    validated_data[field] = primary_lang_value

        return translations_data

    def update_translations(self, instance, translations_data, skip_primary=False):
        for field, value in translations_data.items():
            for lang_code, text in value.items():
                if skip_primary and lang_code == settings.LANGUAGE_CODE:
                    continue
                self.set_translation(instance, field, lang_code, text)

    def set_translation(self, instance, field, lang_code, text):
        if lang_code != settings.LANGUAGE_CODE:
            Translation.objects.update_or_create(
                content_type=ContentType.objects.get_for_model(instance),
                object_id=instance.id,
                field_name=field,
                language=lang_code,
                defaults={'field_value': text}
            )


class TranslatableGettextSerializer(serializers.ModelSerializer):
    class Meta:
        model = None

    def to_representation(self, instance):
        data = super().to_representation(instance)
        for field_name in instance.translatable_fields:
            if field_name in self.fields:
                value = getattr(instance, field_name)
                data[field_name] = GetTextCharField().to_representation(value)
        return data


class TranslatableGettextDictSerializer(serializers.ModelSerializer):
    class Meta:
        model = None

    def to_representation(self, instance):
        data = super().to_representation(instance)
        for field_name in instance.translatable_fields:
            if field_name in self.fields:
                translations = {}
                for lang_code, lang_name in settings.LANGUAGES:
                    value = getattr(instance, field_name)
                    if lang_code == settings.LANGUAGE_CODE:
                        translations[lang_code] = value
                    with translation.override(lang_code):
                        translated_value = GetTextCharField().to_representation(value)
                        if value != translated_value:
                            translations[lang_code] = translated_value
                data[field_name] = translations
        return data



import os
import threading

import polib
from django.apps import apps
from django.conf import settings
from django.contrib.contenttypes.models import ContentType
from django.core.management.base import BaseCommand

from django_restful_translator.models import TranslatableModel, Translation


class Command(BaseCommand):
    help = 'Import .po files to DB translations'

    def handle_language(self, language_set):
        language = language_set[0]

        # Skip default language
        if language == settings.LANGUAGE_CODE:
            return

        # Open the .po file for this language
        po_file_path = os.path.join(settings.BASE_DIR, 'drt_locale', language, 'LC_MESSAGES', 'django.po')

        # Check the last modification time of the .po file
        if os.path.isfile(po_file_path):
            po_file_mod_time = os.path.getmtime(po_file_path)
            try:
                # Get the last update time of the Translation objects for the current language
                last_translation_update = Translation.objects.filter(language=language).latest(
                    'updated_at').updated_at.timestamp()
                # Only proceed if the .po file is newer than the last update in the database
                if po_file_mod_time <= last_translation_update:
                    print(f"Skipping {language} because the .po file is older than the last update in the database")
                    return
            except Translation.DoesNotExist:
                pass

        if not os.path.isfile(po_file_path):
            return

        po = polib.pofile(po_file_path)

        models = apps.get_models()
        translatable_models = [model for model in models if issubclass(model, TranslatableModel)]

        # Iterate over each entry in the .po file
        for entry in po:
            for comment in entry.tcomment.splitlines():
                model_name, field_name, object_id = comment.split("__")
                model = next((m for m in translatable_models if m._meta.model_name == model_name), None)
                if not model:
                    continue
                field_value = entry.msgstr
                if field_value == "":
                    continue
                # Fetch or create the Translation object
                trans, created = Translation.objects.update_or_create(
                    content_type=ContentType.objects.get_for_model(model),
                    object_id=object_id,
                    field_name=field_name,
                    language=language,
                    defaults={"field_value": field_value}
                )
                # If the Translation object already existed, update it
                if not created:
                    trans.field_value = entry.msgstr
                    trans.save()

    def handle(self, *args, **options):
        threads = []
        for language_set in settings.LANGUAGES:
            t = threading.Thread(target=self.handle_language, args=(language_set,))
            t.start()
            threads.append(t)

        for t in threads:
            t.join()



import os
import threading

import polib
from django.conf import settings
from django.core.management.base import BaseCommand

from django_restful_translator.utils import fetch_translatable_fields, get_po_file_path, get_po_metadata


class Command(BaseCommand):
    help = 'Generate .po files from DB translations'

    def generate_po_for_language(self, language_set):
        language = language_set[0]
        po_file_path = get_po_file_path(language)

        if os.path.isfile(po_file_path):
            po = polib.pofile(po_file_path)
        else:
            po = polib.POFile()

        translations = fetch_translatable_fields(language)

        for trans in translations:
            self.write_to_po_file(po, trans)

        po.metadata = get_po_metadata()
        po.save(po_file_path)

    def write_to_po_file(self, po, trans):
        msgid_value = getattr(trans.content_object, trans.field_name)

        # Find existing entry in po file by msgid
        existing_entry = po.find(msgid_value)

        comment = f"{trans.content_object._meta.model_name}__{trans.field_name}__{trans.object_id}"

        # If the msgid already exists, append a comment; otherwise, add a new entry.
        if existing_entry:
            if comment not in existing_entry.tcomment:
                existing_entry.tcomment += f"\n{comment}"
        else:
            entry = polib.POEntry(
                msgid=msgid_value,
                msgstr=trans.field_value,
                tcomment=comment
            )
            if not trans.field_value:
                entry.flags.append('fuzzy')
            po.append(entry)

    def handle(self, *args, **options):
        threads = []

        for language_set in settings.LANGUAGES:
            t = threading.Thread(target=self.generate_po_for_language, args=(language_set,))
            t.start()
            threads.append(t)

        for t in threads:
            t.join()



import os
import threading

import polib
from django.apps import apps
from django.conf import settings
from django.core.management.base import BaseCommand
from django.db import models

from django_restful_translator.models import TranslatableModel
from django_restful_translator.utils import get_po_file_path, get_po_metadata


class Command(BaseCommand):
    help = 'Process existing .po files and regenerate them with specific comments'
    found_objects_cache = {}

    def add_arguments(self, parser):
        parser.add_argument(
            '--locale',
            type=str,
            help='Specify the locale folder name'
        )
        parser.add_argument(
            '--remove-used',
            action='store_true',
            help='Remove entries used in the new .po file from the original .po file'
        )

    def handle(self, *args, **options):
        threads = []
        locale = options['locale']
        remove_used = options['remove_used']

        for language_code, _ in settings.LANGUAGES:
            t = threading.Thread(target=self.process_language, args=(locale, language_code, remove_used))
            t.start()
            threads.append(t)

        for t in threads:
            t.join()

    def process_language(self, locale, language_code, remove_used):
        read_po_file_path = os.path.join(settings.BASE_DIR, locale, language_code, 'LC_MESSAGES', 'django.po')
        save_po_file_path = get_po_file_path(language_code)

        if not os.path.isfile(read_po_file_path):
            self.stdout.write(self.style.WARNING(f"No .po file found for {language_code}."))
            return

        po = polib.pofile(read_po_file_path)
        new_po, used_entries = self.process_po_file(po)
        new_po.save(save_po_file_path)

        if remove_used:
            self.remove_used_entries(po, used_entries)
            po.save(read_po_file_path)

    def process_po_file(self, po):
        new_po = polib.POFile()
        used_entries = []

        for entry in po:
            objects_with_fields = self.find_original_objects(entry.msgid)
            if objects_with_fields:
                new_entry = self.create_new_entry(entry, objects_with_fields)
                new_po.append(new_entry)
                used_entries.append(entry)

        new_po.metadata = get_po_metadata()
        return new_po, used_entries

    def remove_used_entries(self, po, used_entries):
        for entry in used_entries:
            po.remove(entry)

    def create_new_entry(self, entry, objects_with_fields):
        tcomments = [
            f"{obj._meta.model_name}__{field_name}__{obj.pk}"
            for obj, field_name in objects_with_fields
        ]
        return polib.POEntry(
            msgid=entry.msgid,
            msgstr=entry.msgstr,
            tcomment="\n".join(tcomments)
        )

    def find_original_objects(self, msgid):
        if msgid in self.found_objects_cache:
            return self.found_objects_cache[msgid]

        translatable_models = [
            model for model in apps.get_models() if issubclass(model, TranslatableModel)
        ]

        objects_found = []

        for model in translatable_models:
            filters = models.Q()
            for field_name in getattr(model, 'translatable_fields', []):
                filters |= models.Q(**{field_name: msgid})

            objs = model.objects.filter(filters)

            for obj in objs:
                field_name = next(
                    (field for field in getattr(model, 'translatable_fields', []) if getattr(obj, field) == msgid),
                    None
                )
                if field_name:
                    objects_found.append((obj, field_name))

        self.found_objects_cache[msgid] = objects_found if objects_found else None
        return self.found_objects_cache[msgid]



from django import forms
from django.conf import settings
from django.contrib.contenttypes.admin import GenericTabularInline
from django.contrib.contenttypes.forms import BaseGenericInlineFormSet

from django_restful_translator.models import Translation


class TranslationFormSet(BaseGenericInlineFormSet):
    def clean(self):
        super().clean()

        # We'll keep track of unique values as we go
        unique_values = set()
        for form in self.forms:
            # Skip empty forms or forms with errors
            if not form.is_valid() or form in self.deleted_forms:
                continue

            language = form.cleaned_data['language']
            field_name = form.cleaned_data['field_name']

            # Check if this combination already exists
            if (language, field_name) in unique_values:
                raise forms.ValidationError("Translation already exists for this language and field name.")
            unique_values.add((language, field_name))


class TranslationForm(forms.ModelForm):
    class Meta:
        model = Translation
        fields = '__all__'


class TranslationInline(GenericTabularInline):
    model = Translation
    form = TranslationForm
    formset = TranslationFormSet
    extra = 0

    def get_formset(self, request, obj=None, **kwargs):
        formset = super().get_formset(request, obj, **kwargs)
        formset.parent_obj = obj
        return formset

    def formfield_for_dbfield(self, db_field, request, **kwargs):
        field = super().formfield_for_dbfield(db_field, request, **kwargs)
        if db_field.name == 'field_name':
            if hasattr(self, 'parent_model') and self.parent_model:
                field.widget = forms.Select(choices=[(f, f) for f in self.parent_model.translatable_fields])
        return field

    def formfield_for_choice_field(self, db_field, request, **kwargs):
        field = super().formfield_for_choice_field(db_field, request, **kwargs)
        if db_field.name == 'language':
            field.choices = [choice for choice in field.choices if choice[0] != settings.LANGUAGE_CODE]
        return field



from abc import ABC, abstractmethod
from typing import (
    Iterable,
    Union,
)

import boto3
import deepl
from django.conf import settings
from google.cloud import translate_v2, translate


class TranslationProvider(ABC):
    name = "Base Provider"
    batch_size = 1

    @abstractmethod
    def translate_text(self, text: Union[str, Iterable[str]], source_language: str, target_language: str) -> Union[
        str, Iterable[str]]:
        pass


class GoogleTranslateProvider(TranslationProvider):
    name = "google_v2"
    batch_size = 1

    def __init__(self):
        self.client = translate_v2.Client()

    def translate_text(self, text, source_language, target_language):
        result = self.client.translate(text, source_language=source_language, target_language=target_language)
        return result['translatedText']


class AWSTranslateProvider(TranslationProvider):
    name = "aws"
    batch_size = 1

    def __init__(self):
        if not (hasattr(settings, 'AWS_ACCESS_KEY_ID') and hasattr(settings, 'AWS_SECRET_ACCESS_KEY') and hasattr(
                settings, 'AWS_REGION_NAME')):
            raise ValueError("AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY and AWS_REGION_NAME must be set in settings")
        self.client = boto3.client('translate', region_name=settings.AWS_REGION_NAME,
                                   aws_access_key_id=settings.AWS_ACCESS_KEY_ID,
                                   aws_secret_access_key=settings.AWS_SECRET_ACCESS_KEY)

    def translate_text(self, text, source_language, target_language):
        response = self.client.translate_text(Text=text, SourceLanguageCode=source_language,
                                              TargetLanguageCode=target_language)
        return response['TranslatedText']


class GoogleV3TranslateProvider(TranslationProvider):
    name = "google_v3"
    batch_size = 50

    def __init__(self):
        if not hasattr(settings, 'GOOGLE_CLOUD_PROJECT'):
            raise ValueError("GOOGLE_CLOUD_PROJECT must be set in settings")
        if not hasattr(settings, 'GOOGLE_CLOUD_LOCATION'):
            raise ValueError("GOOGLE_CLOUD_LOCATION must be set in settings")
        self.client = translate.TranslationServiceClient()

    def translate_text(self, text, source_language, target_language):
        parent = f"projects/{settings.GOOGLE_CLOUD_PROJECT}/locations/{settings.GOOGLE_CLOUD_LOCATION}"
        if isinstance(text, list):
            results = self.client.translate_text(parent=parent, contents=text, source_language_code=source_language,
                                                 target_language_code=target_language)
            return [result.translated_text for result in results.translations]
        else:
            results = self.client.translate_text(parent=parent, contents=[text], source_language_code=source_language,
                                                 target_language_code=target_language)

            return results.translations[0].translated_text


class DeeplTranslateProvider(TranslationProvider):
    name = "deepl"
    batch_size = 50

    def __init__(self):
        if not hasattr(settings, 'DEEPL_AUTH_KEY'):
            raise ValueError("DEEPL_AUTH_KEY must be set in settings")
        self.client = deepl.Translator(settings.DEEPL_AUTH_KEY)

    def translate_text(self, text, source_language, target_language):
        results = self.client.translate_text(text, source_lang=source_language, target_lang=target_language)
        if isinstance(text, list):
            return [result.text for result in results]
        else:
            return results.text



from django.utils.translation import gettext_lazy as _
from rest_framework import serializers


class GetTextCharField(serializers.CharField):
    def to_representation(self, value):
        return str(_(value)) or value


class GetTextListField(serializers.ListField):
    def to_representation(self, values):
        output = []
        for value in values:
            output.append(str(_(value)) or value)
        return output


class AutoTranslatableDictField(serializers.DictField):
    def to_representation(self, value):
        return {}



from setuptools import setup, find_packages

setup(
    name='django_restful_translator',
    version='0.9.2',
    author='Alex Ivanchyk',
    author_email='alexander.ivanchik@gmail.com',
    description='A Django application providing translation functionalities for Django Rest Framework',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/AlexIvanchyk/django_restful_translator',
    packages=find_packages(),
    install_requires=[
        'Django>=3.2',
        'djangorestframework>=3.11',
        'polib>=1.1',
        'google-cloud-translate>=2.0.4',
        'boto3>=1.26.31',
        'deepl>=1.16.1'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.9',
    ],
    license='MIT',
    python_requires='>=3.7',
    keywords='django rest-framework translation i18n',
)



# Generated by Django 4.2 on 2023-06-22 15:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
    ]

    operations = [
        migrations.CreateModel(
            name='Translation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('object_id', models.CharField(max_length=255)),
                ('language', models.CharField(choices=[('en', 'English'), ('sv', 'Swedish')], max_length=10)),
                ('field_name', models.CharField(max_length=255)),
                ('field_value', models.TextField()),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.contenttype')),
            ],
            options={
                'unique_together': {('content_type', 'object_id', 'language', 'field_name')},
            },
        ),
    ]
